# WriteCloud

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**provider** | [**CloudProviders**](CloudProviders.md) |  | 
**name** | **str** |  | 
**region** | **str** |  | 
**credentials** | **str** |  | 
**creator_id** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


